pub fn diff_test(
c_code: &str,
rust_code: &str,
config: &DiffTestConfig,
) -> Result<DiffTestResult>Expand description
Run a full differential test: compile C with gcc, compile Rust with rustc, execute both, and compare outputs.
pub fn diff_test(
c_code: &str,
rust_code: &str,
config: &DiffTestConfig,
) -> Result<DiffTestResult>Run a full differential test: compile C with gcc, compile Rust with rustc, execute both, and compare outputs.